@@ -1,6 +1,6 @@
 package Email::Sender::Transport::Mbox;
-BEGIN {
-  $Email::Sender::Transport::Mbox::VERSION = '0.110001';
+{
+  $Email::Sender::Transport::Mbox::VERSION = '0.110005';
 }
 use Moose;
 with 'Email::Sender::Transport';
@@ -58,6 +58,8 @@ sub _open_fh {
   my $fh = IO::File->new($file, '>>')
     or Carp::confess "couldn't open $file for appending: $!";
 
+  $fh->binmode(':raw');
+
   $class->_getlock($fh, $file);
 
   $fh->seek(0, 2);
@@ -115,7 +117,7 @@ Email::Sender::Transport::Mbox - deliver mail to an mbox on disk
 
 =head1 VERSION
 
-version 0.110001
+version 0.110005
 
 =head1 DESCRIPTION
 
@@ -131,7 +133,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo Signes.
+This software is copyright (c) 2012 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
